==> lovis4u-0.0.3.6.tar.gz: lovis4u-0.0.3.6/docs/pypi.md <==


<img  src="https://raw.githubusercontent.com/art-egorov/lovis4u/main/docs/img/lovis4u_logo.png" width="310"/>

## Description

**LoVis4u** is a bioinformatics tool for **Lo**ci **Vis**ualisation.

**Supported input**: Genbank, gff3 with sequence    
**Supported output**: Static vector graphics (pdf)   
**Programming language:** Python3   
**OS:** MacOS, Linux  
**Python dependencies:** biopython, bcbio-gff, scipy, configs, argparse, pandas, distinctipy, matplotlib, seaborn, reportlab  
**Python version:** >= 3.8  
**OS-level dependencies:** MMseqs2 (included in the package)  
**License:** WTFPL  
**Version:** 0.0.3 (May 2024)

**Detailed documentation with user guide is available at [LoVis4u Homepage](https://art-egorov.github.io/lovis4u/)**

## Reference 📃

If you find lovis4u useful, please cite:  
Artyom. A. Egorov, Gemma C. Atkinson, **lovis4u: ---**, *---*

## Contact 📇

Please contact us by e-mail _artem**dot**egorov**AT**med**dot**lu**dot**se_ or use [Issues](https://github.com/art-egorov/lovis4u/issues?q=) to report any technical problems.  
You can also use [Discussions section](https://github.com/art-egorov/lovis4u/discussions) for sharing your ideas or feature requests! 

## Authors 👨🏻‍💻

LoVis4u is developed by Artyom Egorov at [the Atkinson Lab](https://atkinson-lab.com), Department of Experimental Medical Science, Lund University, Sweden 🇸🇪. We are open for suggestions to extend and improve LoVis4u functionality. Please don't hesitate to share your ideas or feature requests.

==> lovis4u-0.0.5.tar.gz: lovis4u-0.0.5/docs/pypi.md <==


<img  src="https://raw.githubusercontent.com/art-egorov/lovis4u/main/docs/img/lovis4u_logo.png" width="310"/>

## Description

**LoVis4u** is a bioinformatics tool for **Lo**ci **Vis**ualisation.

**Supported input**: Genbank, gff3 with sequence    
**Supported output**: Static vector graphics (pdf)   
**Programming language:** Python3   
**OS:** MacOS, Linux  
**Python dependencies:** biopython, bcbio-gff, scipy, configs, argparse, pandas, distinctipy, matplotlib, seaborn, reportlab  
**Python version:** >= 3.8  
**OS-level dependencies:** MMseqs2 (included in the package)  
**License:** WTFPL  
**Version:** 0.0.4 (June 2024)

**Detailed documentation with user guide is available at [LoVis4u Homepage](https://art-egorov.github.io/lovis4u/)**

## Reference 📃

If you find lovis4u useful, please cite:  
Artyom. A. Egorov, Gemma C. Atkinson, **lovis4u: ---**, *---*

## Contact 📇

Please contact us by e-mail _artem**dot**egorov**AT**med**dot**lu**dot**se_ or use [Issues](https://github.com/art-egorov/lovis4u/issues?q=) to report any technical problems.  
You can also use [Discussions section](https://github.com/art-egorov/lovis4u/discussions) for sharing your ideas or feature requests! 

## Authors 👨🏻‍💻

LoVis4u is developed by Artyom Egorov at [the Atkinson Lab](https://atkinson-lab.com), Department of Experimental Medical Science, Lund University, Sweden 🇸🇪. We are open for suggestions to extend and improve LoVis4u functionality. Please don't hesitate to share your ideas or feature requests.
